from distutils.core import setup

setup(
        name         = 'didi_nester',
        version      = '1.0.0',
        py_modules   = ['didi_nester'],
        author       = 'hfpython',
        author_email = 'didistonecold@live.com',
        url          = '',
        description  = 'A simple printer of nested lists',
)
